marionette-client
=================

marionette_client has been renamed and is now available as marionette-harness:

* marionette-harness <https://pypi.python.org/pypi/marionette-harness/>`_

Please consider migrating to this new package.
